@@ -8,11 +8,15 @@
         and thus help debugging in pycatia.
         
 """
+from typing import TYPE_CHECKING
 
 from pycatia.drafting_interfaces.drawing_component import DrawingComponent
 from pycatia.system_interfaces.collection import Collection
 from pycatia.types import cat_variant
 
+if TYPE_CHECKING:
+    from pycatia.drafting_interfaces.drawing_view import DrawingView
+
 
 class DrawingComponents(Collection):
     """
@@ -174,5 +178,11 @@ class DrawingComponents(Collection):
         """
         return self.drawing_components.Remove(i_index)
 
+    def __getitem__(self, n: int) -> DrawingComponent:
+        if (n + 1) > self.count:
+            raise StopIteration
+
+        return DrawingComponent(self.drawing_components.item(n + 1))
+
     def __repr__(self):
         return f'DrawingComponents()'
