@@ -203,5 +203,11 @@ class DrawingViews(Collection):
         """
         return self.drawing_views.Remove(i_index)
 
+    def __getitem__(self, n: int) -> DrawingView:
+        if (n + 1) > self.count:
+            raise StopIteration
+
+        return DrawingView(self.drawing_views.item(n + 1))
+
     def __repr__(self):
         return f'DrawingViews(name="{self.name}")'
