@@ -9,6 +9,8 @@
 
 """
 
+from typing import TYPE_CHECKING
+
 from pathlib import Path
 
 from pycatia.exception_handling import CATIAApplicationException
@@ -22,11 +24,14 @@ from pycatia.space_analyses_interfaces.spa_workbench import SPAWorkbench
 from pycatia.system_interfaces.any_object import AnyObject
 from pycatia.drafting_interfaces.drawing_root import DrawingRoot
 
+if TYPE_CHECKING:
+    from pycatia.in_interfaces.selection import Selection
+
 
 class Document(AnyObject):
     """
         .. note::
-            :class: toggle
+            :class: toggle pytoggle
 
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
 
@@ -167,7 +172,6 @@ class Document(AnyObject):
 
         :return: bool
         """
-
         if self.product().is_catproduct():
             return True
         return False
@@ -451,7 +455,6 @@ class Document(AnyObject):
         return Workbench(self.document.GetWorkbench(workbench_name))
 
     def export_data(self, file_name: str, file_type: str, overwrite=False) -> None:
-
         """
         .. note::
             :class: toggle
@@ -775,6 +778,8 @@ class Document(AnyObject):
         """
         Save the document to a new name.
 
+        If overwrite is True CAA.DisplayFileAlerts is set to False.
+
         .. note::
             :class: toggle
 
@@ -794,21 +799,24 @@ class Document(AnyObject):
                 |
                 |          Doc.SaveAs("NewName")
 
-        :param str file_name: full pathname to new file_name
+        :param file_name: full pathname to new file_name
         :param bool overwrite:
         :return: None.
         :rtype: None
         """
 
-        file_name = Path(file_name)
+        path_file_name = Path(file_name)
+
         if overwrite is False:
-            if file_name.is_file():
-                raise FileExistsError(f'File: {file_name} already exists. '
+            if path_file_name.is_file():
+                raise FileExistsError(f'File: {path_file_name} already exists. '
                                       f'Set overwrite=True if you want to overwrite.')
         else:
-            if file_name.is_file():
-                self.logger.warning('File already exists. Click YES in CATIA V5.')
-        self.document.SaveAs(file_name)
+            self.document.Application.DisplayFileAlerts = False
+            # if path_file_name.is_file():
+            #     self.logger.warning('File already exists. Click YES in CATIA V5.')
+
+        self.document.SaveAs(path_file_name)
 
     def search_for_items(self, selection_objects):
         """
