@@ -127,5 +127,11 @@ class LightSources(Collection):
         """
         return self.light_sources.Remove(i_index)
 
+    def __getitem__(self, n: int) -> LightSource:
+        if (n + 1) > self.count:
+            raise StopIteration
+
+        return LightSource(self.light_sources.item(n + 1))
+
     def __repr__(self):
         return f'LightSources(name="{self.name}")'
