@@ -16,6 +16,8 @@ class IntParam(Parameter):
 
     """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
 
                 | System.IUnknown
@@ -46,6 +48,8 @@ class IntParam(Parameter):
     def range_max(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                 | o Property RangeMax() As long
                 | 
@@ -79,6 +83,8 @@ class IntParam(Parameter):
     def range_max_validity(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                 | o Property RangeMaxValidity() As long
                 | 
@@ -110,6 +116,8 @@ class IntParam(Parameter):
     def range_min(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                 | o Property RangeMin() As long
                 | 
@@ -143,6 +151,8 @@ class IntParam(Parameter):
     def range_min_validity(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                 | o Property RangeMinValidity() As long
                 | 
@@ -174,6 +184,8 @@ class IntParam(Parameter):
     def value(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                 | o Property Value() As long
                 | 
@@ -205,6 +217,8 @@ class IntParam(Parameter):
     def get_enumerate_values(self, o_safe_array: tuple) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                 | o Sub GetEnumerateValues(CATSafeArrayVariant oSafeArray)
                 | 
@@ -239,12 +253,14 @@ class IntParam(Parameter):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def get_enumerate_values_size(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                 | o Func GetEnumerateValuesSize() As long
                 | 
@@ -258,6 +274,8 @@ class IntParam(Parameter):
     def set_enumerate_values(self, i_safe_array: tuple) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                 | o Sub SetEnumerateValues(CATSafeArrayVariant iSafeArray)
                 | 
@@ -282,12 +300,14 @@ class IntParam(Parameter):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def suppress_enumerate_values(self) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                 | o Sub SuppressEnumerateValues()
                 | 
