@@ -9,12 +9,17 @@
         
 """
 
+from typing import TYPE_CHECKING
+
 from pycatia.mec_mod_interfaces.geometric_elements import GeometricElements
 from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape
 from pycatia.mec_mod_interfaces.hybrid_shapes import HybridShapes
 from pycatia.mec_mod_interfaces.sketches import Sketches
 from pycatia.system_interfaces.any_object import AnyObject
 
+if TYPE_CHECKING:
+    from pycatia.mec_mod_interfaces.bodies import Bodies
+    from pycatia.mec_mod_interfaces.hybrid_bodies import HybridBodies
 
 class HybridBody(AnyObject):
     """
