@@ -99,5 +99,11 @@ class Shapes(Collection):
         """
         return Shape(self.shapes.Item(i_index))
 
+    def __getitem__(self, n: int) -> Shape:
+        if (n + 1) > self.count:
+            raise StopIteration
+
+        return Shape(self.shapes.item(n + 1))
+
     def __repr__(self):
         return f'Shapes(name="{self.name}")'
