@@ -79,7 +79,7 @@ class MarkerSettingAtt(SettingController):
                 | 
                 | 
                 | MarkerTextDefaultsSize3D
-    
+
     """
 
     def __init__(self, com_object):
@@ -268,7 +268,7 @@ class MarkerSettingAtt(SettingController):
         self.marker_setting_att.MarkerTextDefaultsFont2D = value
 
     @property
-    def marker_text_defaults_font_3d(self) -> False:
+    def marker_text_defaults_font_3d(self) -> str:
         """
         .. note::
             :class: toggle
@@ -278,16 +278,16 @@ class MarkerSettingAtt(SettingController):
                 | 
                 |     Returns or sets the default font of a 3D annotation (oValue the font name).
 
-        :return: False
-        :rtype: False
+        :return: str
+        :rtype: str
         """
 
-        return None
+        return self.marker_setting_att.MarkerTextDefaultsFont3D
 
     @marker_text_defaults_font_3d.setter
-    def marker_text_defaults_font_3d(self, value: False):
+    def marker_text_defaults_font_3d(self, value: str):
         """
-        :param False value:
+        :param str value:
         """
 
         self.marker_setting_att.MarkerTextDefaultsFont3D = value
@@ -319,7 +319,7 @@ class MarkerSettingAtt(SettingController):
         self.marker_setting_att.MarkerTextDefaultsSize2D = value
 
     @property
-    def marker_text_defaults_size_3d(self) -> False:
+    def marker_text_defaults_size_3d(self) -> int:
         """
         .. note::
             :class: toggle
@@ -330,16 +330,16 @@ class MarkerSettingAtt(SettingController):
                 |     Returns or sets the default size value of a 3d annotation (oValue the size
                 |     value)..
 
-        :return: False
-        :rtype: False
+        :return: int
+        :rtype: int
         """
 
-        return None
+        return self.marker_setting_att.MarkerTextDefaultsSize3D
 
     @marker_text_defaults_size_3d.setter
-    def marker_text_defaults_size_3d(self, value: False):
+    def marker_text_defaults_size_3d(self, value: int):
         """
-        :param False value:
+        :param int value:
         """
 
         self.marker_setting_att.MarkerTextDefaultsSize3D = value
@@ -371,7 +371,7 @@ class MarkerSettingAtt(SettingController):
         self.marker_setting_att.MarkerTextWeight2D = value
 
     @property
-    def marker_text_weight_3d(self) -> False:
+    def marker_text_weight_3d(self) -> int:
         """
         .. note::
             :class: toggle
@@ -382,16 +382,16 @@ class MarkerSettingAtt(SettingController):
                 |     Returns or sets the default weight value of a 3D text annotation (oValue
                 |     the weight value).
 
-        :return: False
-        :rtype: False
+        :return: int
+        :rtype: int
         """
 
-        return None
+        return self.marker_setting_att.MarkerTextWeight3D
 
     @marker_text_weight_3d.setter
-    def marker_text_weight_3d(self, value: False):
+    def marker_text_weight_3d(self, value: int):
         """
-        :param False value:
+        :param int value:
         """
 
         self.marker_setting_att.MarkerTextWeight3D = value
@@ -1040,7 +1040,7 @@ class MarkerSettingAtt(SettingController):
         :rtype: None
         """
         return self.marker_setting_att.SetMarker2DAutoNamingLock(i_locked)
-        # # # # Autogenerated comment: 
+        # # # # Autogenerated comment:
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
         # # should be uncommented and edited accordingly. Otherwise completely remove all this.
@@ -1082,7 +1082,7 @@ class MarkerSettingAtt(SettingController):
         :rtype: None
         """
         return self.marker_setting_att.SetMarker3DAutoNamingLock(i_locked)
-        # # # # Autogenerated comment: 
+        # # # # Autogenerated comment:
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
         # # should be uncommented and edited accordingly. Otherwise completely remove all this.
@@ -1145,7 +1145,7 @@ class MarkerSettingAtt(SettingController):
         :rtype: None
         """
         return self.marker_setting_att.SetMarkerDefaultsColorLock(i_locked)
-        # # # # Autogenerated comment: 
+        # # # # Autogenerated comment:
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
         # # should be uncommented and edited accordingly. Otherwise completely remove all this.
@@ -1187,7 +1187,7 @@ class MarkerSettingAtt(SettingController):
         :rtype: None
         """
         return self.marker_setting_att.SetMarkerDefaultsDashedLock(i_locked)
-        # # # # Autogenerated comment: 
+        # # # # Autogenerated comment:
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
         # # should be uncommented and edited accordingly. Otherwise completely remove all this.
@@ -1229,7 +1229,7 @@ class MarkerSettingAtt(SettingController):
         :rtype: None
         """
         return self.marker_setting_att.SetMarkerDefaultsWeightLock(i_locked)
-        # # # # Autogenerated comment: 
+        # # # # Autogenerated comment:
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
         # # should be uncommented and edited accordingly. Otherwise completely remove all this.
@@ -1292,7 +1292,7 @@ class MarkerSettingAtt(SettingController):
         :rtype: None
         """
         return self.marker_setting_att.SetMarkerTextColor2DLock(i_locked)
-        # # # # Autogenerated comment: 
+        # # # # Autogenerated comment:
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
         # # should be uncommented and edited accordingly. Otherwise completely remove all this.
@@ -1355,7 +1355,7 @@ class MarkerSettingAtt(SettingController):
         :rtype: None
         """
         return self.marker_setting_att.SetMarkerTextColor3DLock(i_locked)
-        # # # # Autogenerated comment: 
+        # # # # Autogenerated comment:
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
         # # should be uncommented and edited accordingly. Otherwise completely remove all this.
@@ -1397,7 +1397,7 @@ class MarkerSettingAtt(SettingController):
         :rtype: None
         """
         return self.marker_setting_att.SetMarkerTextDashed2DLock(i_locked)
-        # # # # Autogenerated comment: 
+        # # # # Autogenerated comment:
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
         # # should be uncommented and edited accordingly. Otherwise completely remove all this.
@@ -1439,7 +1439,7 @@ class MarkerSettingAtt(SettingController):
         :rtype: None
         """
         return self.marker_setting_att.SetMarkerTextDashed3DLock(i_locked)
-        # # # # Autogenerated comment: 
+        # # # # Autogenerated comment:
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
         # # should be uncommented and edited accordingly. Otherwise completely remove all this.
@@ -1481,7 +1481,7 @@ class MarkerSettingAtt(SettingController):
         :rtype: None
         """
         return self.marker_setting_att.SetMarkerTextDefaultsFont2DLock(i_locked)
-        # # # # Autogenerated comment: 
+        # # # # Autogenerated comment:
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
         # # should be uncommented and edited accordingly. Otherwise completely remove all this.
@@ -1523,7 +1523,7 @@ class MarkerSettingAtt(SettingController):
         :rtype: None
         """
         return self.marker_setting_att.SetMarkerTextDefaultsFont3DLock(i_locked)
-        # # # # Autogenerated comment: 
+        # # # # Autogenerated comment:
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
         # # should be uncommented and edited accordingly. Otherwise completely remove all this.
@@ -1565,7 +1565,7 @@ class MarkerSettingAtt(SettingController):
         :rtype: None
         """
         return self.marker_setting_att.SetMarkerTextDefaultsSize2DLock(i_locked)
-        # # # # Autogenerated comment: 
+        # # # # Autogenerated comment:
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
         # # should be uncommented and edited accordingly. Otherwise completely remove all this.
@@ -1607,7 +1607,7 @@ class MarkerSettingAtt(SettingController):
         :rtype: None
         """
         return self.marker_setting_att.SetMarkerTextDefaultsSize3DLock(i_locked)
-        # # # # Autogenerated comment: 
+        # # # # Autogenerated comment:
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
         # # should be uncommented and edited accordingly. Otherwise completely remove all this.
@@ -1649,7 +1649,7 @@ class MarkerSettingAtt(SettingController):
         :rtype: None
         """
         return self.marker_setting_att.SetMarkerTextWeight2DLock(i_locked)
-        # # # # Autogenerated comment: 
+        # # # # Autogenerated comment:
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
         # # should be uncommented and edited accordingly. Otherwise completely remove all this.
@@ -1691,7 +1691,7 @@ class MarkerSettingAtt(SettingController):
         :rtype: None
         """
         return self.marker_setting_att.SetMarkerTextWeight3DLock(i_locked)
-        # # # # Autogenerated comment: 
+        # # # # Autogenerated comment:
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
         # # should be uncommented and edited accordingly. Otherwise completely remove all this.
