@@ -43,6 +43,8 @@ class Measurable(AnyObject):
     def angle(self) -> float:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic help
 
             Property Angle( ) As double (Read Only)
@@ -65,6 +67,8 @@ class Measurable(AnyObject):
     def area(self) -> float:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic help
 
             Property Area( ) As double (Read Only)
@@ -85,6 +89,8 @@ class Measurable(AnyObject):
     def geometry_name(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic help
 
         :return: int
@@ -126,6 +132,8 @@ class Measurable(AnyObject):
     def perimeter(self) -> float:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic help
 
             Property Perimeter( ) As double (Read Only)
@@ -187,6 +195,8 @@ class Measurable(AnyObject):
     def get_angle_between(self, i_measured_item: Reference) -> float:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic help
 
         :param Reference i_measured_item:
@@ -248,7 +258,7 @@ class Measurable(AnyObject):
         End Function
         '''
 
-        system_service = SystemService(self.application.SystemService)
+        system_service = self.application.system_service
         result = system_service.evaluate(vba_code, 0, vba_function_name,
                                          [self.measurable])
 
@@ -294,7 +304,7 @@ class Measurable(AnyObject):
                 {vba_function_name} = Components
             End Function
             '''
-        system_service = SystemService(self.application.SystemService)
+        system_service = self.application.system_service
         result = system_service.evaluate(vba_code, 0, vba_function_name, [self.measurable])
 
         return result
@@ -331,7 +341,7 @@ class Measurable(AnyObject):
         End Function
         '''
 
-        system_service = SystemService(self.application.SystemService)
+        system_service = self.application.system_service
         result = system_service.evaluate(vba_code, 0, vba_function_name, [self.measurable])
 
         return result
@@ -368,7 +378,7 @@ class Measurable(AnyObject):
         End Function
         '''
 
-        system_service = SystemService(self.application.SystemService)
+        system_service = self.application.system_service
         result = system_service.evaluate(vba_code, 0, vba_function_name, [self.measurable])
 
         return result
@@ -376,6 +386,8 @@ class Measurable(AnyObject):
     def get_direction(self):
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic help
 
             Sub GetDirection( CATSafeArrayVariant  oDirection)
@@ -406,7 +418,7 @@ class Measurable(AnyObject):
         End Function
         '''
 
-        system_service = SystemService(self.application.SystemService)
+        system_service = self.application.system_service
         result = system_service.evaluate(vba_code, 0, vba_function_name, [self.measurable])
 
         return result
@@ -415,6 +427,8 @@ class Measurable(AnyObject):
         # noinspection SpellCheckingInspection
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic help
 
             Func GetMinimumDistance( Reference  iMeasuredItem) As double
@@ -452,6 +466,8 @@ class Measurable(AnyObject):
     def get_minimum_distance_points(self, i_measured_item):
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic help
 
             Sub GetMinimumDistancePoints( Reference  iMeasuredItem, CATSafeArrayVariant  oCoordinates)
@@ -484,12 +500,14 @@ class Measurable(AnyObject):
         End Function
         '''
 
-        system_service = SystemService(self.application.SystemService)
+        system_service = self.application.system_service
         return system_service.evaluate(vba_code, 0, vba_function_name, [self.measurable, i_measured_item.com_object])
 
     def get_plane(self):
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic help
 
             Sub GetPlane( CATSafeArrayVariant  oComponents)
@@ -525,12 +543,14 @@ class Measurable(AnyObject):
         End Function
         '''
 
-        system_service = SystemService(self.application.SystemService)
+        system_service = self.application.system_service
         return system_service.evaluate(vba_code, 0, vba_function_name, [self.measurable])
 
     def get_point(self):
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic help
             Sub GetPoint( CATSafeArrayVariant  oCoordinates)
 
@@ -559,12 +579,14 @@ class Measurable(AnyObject):
         End Function
         '''
 
-        system_service = SystemService(self.application.SystemService)
+        system_service = self.application.system_service
         return system_service.evaluate(vba_code, 0, vba_function_name, [self.measurable])
 
     def get_points_on_axis(self):
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic help
 
             Sub GetPointsOnAxis( CATSafeArrayVariant  oCoordinates)
@@ -601,12 +623,14 @@ class Measurable(AnyObject):
         End Function
         '''
 
-        system_service = SystemService(self.application.SystemService)
+        system_service = self.application.system_service
         return system_service.evaluate(vba_code, 0, vba_function_name, [self.measurable])
 
     def get_points_on_curve(self):
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic help
 
             Sub GetPointsOnCurve( CATSafeArrayVariant  oCoordinates)
@@ -642,7 +666,7 @@ class Measurable(AnyObject):
         End Function
         '''
 
-        system_service = SystemService(self.application.SystemService)
+        system_service = self.application.system_service
         return system_service.evaluate(vba_code, 0, vba_function_name, [self.measurable])
 
     def __repr__(self):
