@@ -9,12 +9,16 @@
 
 """
 
+from typing import TYPE_CHECKING
+
 from pycatia.base_interfaces.pycatia import PyCATIA
 from pycatia.system_interfaces.any_object import AnyObject
 
-
 # from pycatia.system_interfaces.cat_base_dispatch import CATBaseDispatch
 
+if TYPE_CHECKING:
+    from pycatia.in_interfaces.application import Application
+
 
 class Collection(PyCATIA):
     """
@@ -217,5 +221,15 @@ class Collection(PyCATIA):
 
         return items_list
 
+    def __len__(self):
+
+        return self.count
+
+    def __getitem__(self, n: int) -> AnyObject:
+
+        if (n + 1) > self.count:
+            raise StopIteration
+        return self.child_object(self.com_object.item(n + 1))
+
     def __repr__(self):
         return f'Collection(name="{self.name}")'
