@@ -16,6 +16,8 @@ class DisconnectionSettingAtt(SettingController):
 
     """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
 
                 | System.IUnknown
@@ -41,6 +43,8 @@ class DisconnectionSettingAtt(SettingController):
     def activation_state(self):
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                 | o Property ActivationState() As boolean
                 | 
@@ -65,6 +69,8 @@ class DisconnectionSettingAtt(SettingController):
     def inactivity_duration(self):
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                 | o Property InactivityDuration() As long
                 | 
@@ -88,6 +94,8 @@ class DisconnectionSettingAtt(SettingController):
     def get_activation_state_info(self, admin_level, o_locked):
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                 | o Func GetActivationStateInfo(CATBSTR AdminLevel,
                 | CATBSTR oLocked) As boolean
@@ -105,6 +113,8 @@ class DisconnectionSettingAtt(SettingController):
     def get_inactivity_duration_info(self, admin_level, o_locked):
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                 | o Func GetInactivityDurationInfo(CATBSTR AdminLevel,
                 | CATBSTR oLocked) As boolean
@@ -122,6 +132,8 @@ class DisconnectionSettingAtt(SettingController):
     def set_activation_state_lock(self, i_locked):
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                 | o Sub SetActivationStateLock(boolean iLocked)
                 | 
@@ -146,12 +158,14 @@ class DisconnectionSettingAtt(SettingController):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def set_inactivity_duration_lock(self, i_locked):
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                 | o Sub SetInactivityDurationLock(boolean iLocked)
                 | 
@@ -175,7 +189,7 @@ class DisconnectionSettingAtt(SettingController):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def __repr__(self):
